##  SAP LeanIX Is the Source
Consider an example where SAP LeanIX is the source system and ServiceNow is the target system. You can match displayName or name in SAP LeanIX with any valid field in ServiceNow. A relevant matching rule enables the integration to match items between the systems without creating duplicates.
![Example Matching Rule when SAP LeanIX Is the Source System](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741b7527a441014b4a9f2db80dae566_LowRes.png)
Example Matching Rule when SAP LeanIX Is the Source System
